"""hello experimental world"""


def hello():
    print("hello experimental world")


if __name__ == "__main__":
    hello()
